"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _styledBase = _interopRequireDefault(require("@emotion/styled-base"));

var _partial2 = _interopRequireDefault(require("lodash/partial"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactImmutableProptypes = _interopRequireDefault(require("react-immutable-proptypes"));

var _react = _interopRequireDefault(require("react"));

var _netlifyCmsUiDefault = require("@talves/netlify-cms-ui-default");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const LoginButton = (0, _styledBase.default)("button", {
  target: "ey01qwa0",
  label: "LoginButton"
})(_netlifyCmsUiDefault.buttons.button, ";", _netlifyCmsUiDefault.shadows.dropDeep, ";", _netlifyCmsUiDefault.buttons.default, ";", _netlifyCmsUiDefault.buttons.gray, ";padding:0 30px;display:block;margin-top:20px;margin-left:auto;");
const AuthForm = (0, _styledBase.default)("form", {
  target: "ey01qwa1",
  label: "AuthForm"
})({
  name: "olstp8",
  styles: "width:350px;margin-top:-80px;"
});
const AuthInput = (0, _styledBase.default)("input", {
  target: "ey01qwa2",
  label: "AuthInput"
})("background-color:", _netlifyCmsUiDefault.colorsRaw.white, ";border-radius:", _netlifyCmsUiDefault.lengths.borderRadius, ";font-size:14px;padding:10px 10px;margin-bottom:15px;margin-top:6px;width:100%;position:relative;z-index:1;&:focus{outline:none;box-shadow:inset 0 0 0 2px ", _netlifyCmsUiDefault.colors.active, ";}");
const ErrorMessage = (0, _styledBase.default)("p", {
  target: "ey01qwa3",
  label: "ErrorMessage"
})("color:", _netlifyCmsUiDefault.colors.errorText, ";");
let component = null;

if (window.netlifyIdentity) {
  window.netlifyIdentity.on('login', user => {
    component && component.handleIdentityLogin(user);
  });
  window.netlifyIdentity.on('logout', () => {
    component && component.handleIdentityLogout();
  });
}

class GitGatewayAuthenticationPage extends _react.default.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "handleIdentityLogin", user => {
      this.props.onLogin(user);
      window.netlifyIdentity.close();
    });

    _defineProperty(this, "handleIdentityLogout", () => {
      window.netlifyIdentity.open();
    });

    _defineProperty(this, "handleIdentity", () => {
      const user = window.netlifyIdentity.currentUser();

      if (user) {
        this.props.onLogin(user);
      } else {
        window.netlifyIdentity.open();
      }
    });

    _defineProperty(this, "state", {
      email: '',
      password: '',
      errors: {}
    });

    _defineProperty(this, "handleChange", (name, e) => {
      this.setState(_objectSpread({}, this.state, {
        [name]: e.target.value
      }));
    });

    _defineProperty(this, "handleLogin", e => {
      e.preventDefault();
      const _this$state = this.state,
            email = _this$state.email,
            password = _this$state.password;
      const errors = {};

      if (!email) {
        errors.email = 'Make sure to enter your email.';
      }

      if (!password) {
        errors.password = 'Please enter your password.';
      }

      if (Object.keys(errors).length > 0) {
        this.setState({
          errors
        });
        return;
      }

      GitGatewayAuthenticationPage.authClient.login(this.state.email, this.state.password, true).then(user => {
        this.props.onLogin(user);
      }).catch(error => {
        this.setState({
          errors: {
            server: error.description || error.msg || error
          },
          loggingIn: false
        });
      });
    });

    component = this;
  }

  componentDidMount() {
    if (!this.loggedIn && window.netlifyIdentity && window.netlifyIdentity.currentUser()) {
      this.props.onLogin(window.netlifyIdentity.currentUser());
      window.netlifyIdentity.close();
    }
  }

  componentWillUnmount() {
    component = null;
  }

  render() {
    const errors = this.state.errors;
    const _this$props = this.props,
          error = _this$props.error,
          inProgress = _this$props.inProgress,
          config = _this$props.config;

    if (window.netlifyIdentity) {
      return _react.default.createElement(_netlifyCmsUiDefault.AuthenticationPage, {
        logoUrl: config.get('logo_url'),
        onLogin: this.handleIdentity,
        renderButtonContent: () => 'Login with Netlify Identity'
      });
    }

    return _react.default.createElement(_netlifyCmsUiDefault.AuthenticationPage, {
      logoUrl: config.get('logo_url'),
      renderPageContent: () => _react.default.createElement(AuthForm, {
        onSubmit: this.handleLogin
      }, !error ? null : _react.default.createElement(ErrorMessage, null, error), !errors.server ? null : _react.default.createElement(ErrorMessage, null, errors.server), _react.default.createElement(ErrorMessage, null, errors.email || null), _react.default.createElement(AuthInput, {
        type: "text",
        name: "email",
        placeholder: "Email",
        value: this.state.email,
        onChange: (0, _partial2.default)(this.handleChange, 'email')
      }), _react.default.createElement(ErrorMessage, null, errors.password || null), _react.default.createElement(AuthInput, {
        type: "password",
        name: "password",
        placeholder: "Password",
        value: this.state.password,
        onChange: (0, _partial2.default)(this.handleChange, 'password')
      }), _react.default.createElement(LoginButton, {
        disabled: inProgress
      }, inProgress ? 'Logging in...' : 'Login'))
    });
  }

}

exports.default = GitGatewayAuthenticationPage;

_defineProperty(GitGatewayAuthenticationPage, "propTypes", {
  onLogin: _propTypes.default.func.isRequired,
  inProgress: _propTypes.default.bool.isRequired,
  error: _propTypes.default.node,
  config: _reactImmutableProptypes.default.map
});
